@@ -9,18 +9,22 @@
 
 #include <QDialog>
 
+#include <memory>
+
 namespace EventViews
 {
 class Prefs;
 using PrefsPtr = QSharedPointer<Prefs>;
 
+class TimeScaleConfigDialogPrivate;
+
 class TimeScaleConfigDialog : public QDialog, private Ui::TimeScaleEditWidget
 {
     Q_OBJECT
 
 public:
     TimeScaleConfigDialog(const PrefsPtr &preferences, QWidget *parent);
-    ~TimeScaleConfigDialog();
+    ~TimeScaleConfigDialog() override;
 
 private:
     void add();
@@ -33,8 +37,6 @@ private:
     QStringList zones() const;
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<TimeScaleConfigDialogPrivate> const d;
 };
 }
-
