@@ -87,6 +87,8 @@ public:
     QStringList timeScaleTimezones() const;
     void setUse24HourClock(bool enable);
     bool use24HourClock() const;
+    void setUseDualLabels(bool enable);
+    bool useDualLabels() const;
 
     QHash<QString, QColor> mResourceColors;
     QColor mDefaultResourceColor;
@@ -96,6 +98,7 @@ public:
 
     QStringList mTimeScaleTimeZones;
     bool mUse24HourClock = false;
+    bool mUseDualLabels = false;
 
     QSet<EventViews::EventView::ItemIcon> mAgendaViewIcons;
     QSet<EventViews::EventView::ItemIcon> mMonthViewIcons;
@@ -147,6 +150,16 @@ bool BaseConfig::use24HourClock() const
     return mUse24HourClock;
 }
 
+void BaseConfig::setUseDualLabels(bool enable)
+{
+    mUseDualLabels = enable;
+}
+
+bool BaseConfig::useDualLabels() const
+{
+    return mUseDualLabels;
+}
+
 void BaseConfig::usrSetDefaults()
 {
     setAgendaTimeLabelsFont(mDefaultAgendaTimeLabelsFont);
@@ -171,11 +184,12 @@ void BaseConfig::usrRead()
     const QString str = QLocale().timeFormat();
     // 'A' or 'a' means am/pm is shown (and then 'h' uses 12-hour format)
     // but 'H' forces a 24-hour format anyway, even with am/pm shown.
-    if (str.contains(QLatin1Char('a'), Qt::CaseInsensitive) && !str.contains(QLatin1Char('H'))) {
+    if (str.contains(QLatin1Char('a'), Qt::CaseInsensitive) && !str.contains(u'H')) {
         setUse24HourClock(timeScaleConfig.readEntry("24 Hour Clock", false));
     } else {
         setUse24HourClock(timeScaleConfig.readEntry("24 Hour Clock", true));
     }
+    setUseDualLabels(timeScaleConfig.readEntry("Dual Labels", false));
 
     KConfigGroup const monthViewConfig(config(), QStringLiteral("Month View"));
     KConfigGroup const agendaViewConfig(config(), QStringLiteral("Agenda View"));
@@ -198,6 +212,7 @@ bool BaseConfig::usrSave()
     KConfigGroup timeScaleConfig(config(), QStringLiteral("Timescale"));
     timeScaleConfig.writeEntry("Timescale Timezones", timeScaleTimezones());
     timeScaleConfig.writeEntry("24 Hour Clock", use24HourClock());
+    timeScaleConfig.writeEntry("Dual Labels", useDualLabels());
 
     KConfigGroup monthViewConfig(config(), QStringLiteral("Month View"));
     KConfigGroup agendaViewConfig(config(), QStringLiteral("Agenda View"));
@@ -962,6 +977,16 @@ void Prefs::setUse24HourClock(bool enable)
     d->mBaseConfig.setUse24HourClock(enable);
 }
 
+bool Prefs::useDualLabels() const
+{
+    return d->mBaseConfig.useDualLabels();
+}
+
+void Prefs::setUseDualLabels(bool enable)
+{
+    d->mBaseConfig.setUseDualLabels(enable);
+}
+
 KConfigSkeleton::ItemFont *Prefs::fontItem(const QString &name) const
 {
     KConfigSkeletonItem *item = d->mAppConfig ? d->mAppConfig->findItem(name) : nullptr;
