@@ -45,7 +45,6 @@ namespace EventViews
 class RowController : public KGantt::AbstractRowController
 {
 private:
-    static const int ROW_HEIGHT;
     QPointer<QAbstractItemModel> m_model;
 
 public:
@@ -153,7 +152,7 @@ private:
         const KGantt::ItemType type = static_cast<KGantt::ItemType>(idx.model()->data(idx, KGantt::ItemTypeRole).toInt());
 
         const QString txt = idx.model()->data(idx, Qt::DisplayRole).toString();
-        QRectF itemRect = opt.itemRect;
+        const QRectF itemRect = opt.itemRect;
         QRectF boundingRect = opt.boundingRect;
         boundingRect.setY(itemRect.y());
         boundingRect.setHeight(itemRect.height());
@@ -176,7 +175,7 @@ private:
         switch (type) {
         case KGantt::TypeTask:
             if (itemRect.isValid()) {
-                QRectF r = itemRect;
+                const QRectF r = itemRect;
                 painter->drawRect(r);
                 bool drawText = true;
                 Qt::Alignment ta;
@@ -285,7 +284,9 @@ int TimelineView::currentDateCount() const
 void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &preferredMonth)
 {
     Q_UNUSED(preferredMonth)
+    /* cppcheck-suppress assertWithSideEffect */
     Q_ASSERT_X(start.isValid(), "showDates()", "start date must be valid");
+    /* cppcheck-suppress assertWithSideEffect */
     Q_ASSERT_X(end.isValid(), "showDates()", "end date must be valid");
 
     qCDebug(CALENDARVIEW_LOG) << "start=" << start << "end=" << end;
@@ -301,7 +302,8 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
     d->mCalendarItemMap.clear();
 
     uint index = 0;
-    for (const auto &calendar : calendars()) {
+    const auto cals = calendars();
+    for (const auto &calendar : cals) {
         auto item = new TimelineItem(calendar, index++, static_cast<QStandardItemModel *>(d->mGantt->model()), d->mGantt);
         const auto name = Akonadi::CalendarUtils::displayName(calendar->model(), calendar->collection());
         d->mLeftView->addTopLevelItem(new QTreeWidgetItem(QStringList{name}));
@@ -324,14 +326,14 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
     QAbstractItemModel *ganttModel = d->mGantt->model();
     d->mGantt->setModel(nullptr);
 
-    for (const auto &calendar : calendars()) {
+    for (const auto &calendar : cals) {
         for (QDate day = d->mStartDate; day <= d->mEndDate; day = day.addDays(1)) {
             const auto events = calendar->events(day, QTimeZone::systemTimeZone(), KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
             for (const KCalendarCore::Event::Ptr &event : std::as_const(events)) {
                 if (event->hasRecurrenceId()) {
                     continue;
                 }
-                Akonadi::Item item = calendar->item(event);
+                const Akonadi::Item item = calendar->item(event);
                 d->insertIncidence(calendar, item, day);
             }
         }
@@ -352,19 +354,19 @@ void TimelineView::updateView()
     }
 }
 
-void TimelineView::changeIncidenceDisplay(const Akonadi::Item &incidence, int mode)
+void TimelineView::changeIncidenceDisplay(const Akonadi::Item &item, int mode)
 {
-    const auto cal = calendar3(incidence);
+    const auto cal = calendar3(item);
     switch (mode) {
     case Akonadi::IncidenceChanger::ChangeTypeCreate:
-        d->insertIncidence(cal, incidence);
+        d->insertIncidence(cal, item);
         break;
     case Akonadi::IncidenceChanger::ChangeTypeModify:
-        d->removeIncidence(incidence);
-        d->insertIncidence(cal, incidence);
+        d->removeIncidence(item);
+        d->insertIncidence(cal, item);
         break;
     case Akonadi::IncidenceChanger::ChangeTypeDelete:
-        d->removeIncidence(incidence);
+        d->removeIncidence(item);
         break;
     default:
         updateView();
