@@ -5,6 +5,7 @@
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
+// krazy:excludeall=i18ncheckarg internal error for unknown reason
 
 #include "whatsnextview.h"
 using namespace Qt::Literals::StringLiterals;
@@ -26,9 +27,7 @@ using namespace EventViews;
 void WhatsNextTextBrowser::doSetSource(const QUrl &name, QTextDocument::ResourceType type)
 {
     Q_UNUSED(type);
-    if (name.scheme() == "event"_L1) {
-        Q_EMIT showIncidence(name);
-    } else if (name.scheme() == "todo"_L1) {
+    if ((name.scheme() == "event"_L1) || (name.scheme() == "todo"_L1)) {
         Q_EMIT showIncidence(name);
     } else {
         QTextBrowser::setSource(name);
@@ -88,7 +87,8 @@ void WhatsNextView::updateView()
     mText += "</h2>\n"_L1;
 
     KCalendarCore::Event::List events;
-    for (const auto &calendar : calendars()) {
+    const auto cals = calendars();
+    for (const auto &calendar : cals) {
         events += calendar->events(mStartDate, mEndDate, QTimeZone::systemTimeZone(), false);
     }
 
@@ -102,17 +102,17 @@ void WhatsNextView::updateView()
         mText += i18n("Events:") + "</h2>\n"_L1;
         mText += "<table>\n"_L1;
         for (const KCalendarCore::Event::Ptr &ev : std::as_const(events)) {
-            const auto calendar = calendar3(ev);
+            const auto evCalendar = calendar3(ev);
             if (!ev->recurs()) {
-                appendEvent(calendar, ev);
+                appendEvent(evCalendar, ev);
             } else {
                 KCalendarCore::Recurrence *recur = ev->recurrence();
-                int duration = ev->dtStart().secsTo(ev->dtEnd());
-                QDateTime start = recur->getPreviousDateTime(QDateTime(mStartDate, QTime(), QTimeZone::LocalTime));
-                QDateTime end = start.addSecs(duration);
-                QDateTime endDate(mEndDate, QTime(23, 59, 59), QTimeZone::LocalTime);
+                const int duration = ev->dtStart().secsTo(ev->dtEnd());
+                const QDateTime start = recur->getPreviousDateTime(QDateTime(mStartDate, QTime(), QTimeZone::LocalTime));
+                const QDateTime end = start.addSecs(duration);
+                const QDateTime endDate(mEndDate, QTime(23, 59, 59), QTimeZone::LocalTime);
                 if (end.date() >= mStartDate) {
-                    appendEvent(calendar, ev, start.toLocalTime(), end.toLocalTime());
+                    appendEvent(evCalendar, ev, start.toLocalTime(), end.toLocalTime());
                 }
                 const auto times = recur->timesInInterval(start, endDate);
                 int count = times.count();
@@ -125,7 +125,7 @@ void WhatsNextView::updateView()
                         --count; // list overflow
                     }
                     for (; i < count && times[i].date() <= mEndDate; ++i) {
-                        appendEvent(calendar, ev, times[i].toLocalTime());
+                        appendEvent(evCalendar, ev, times[i].toLocalTime());
                     }
                 }
             }
@@ -135,32 +135,32 @@ void WhatsNextView::updateView()
 
     mTodos.clear();
     KCalendarCore::Todo::List todos;
-    for (const auto &calendar : calendars()) {
+    for (const auto &calendar : cals) {
         todos += calendar->todos(KCalendarCore::TodoSortDueDate, KCalendarCore::SortDirectionAscending);
     }
     if (!todos.isEmpty()) {
         bool taskHeaderWasCreated = false;
         for (const KCalendarCore::Todo::Ptr &todo : std::as_const(todos)) {
-            const auto calendar = calendar3(todo);
+            const auto todoCalendar = calendar3(todo);
             if (!todo->isCompleted() && todo->hasDueDate() && todo->dtDue().date() <= mEndDate) {
                 if (!taskHeaderWasCreated) {
                     createTaskRow(kil);
                     taskHeaderWasCreated = true;
                 }
-                appendTodo(calendar, todo);
+                appendTodo(todoCalendar, todo);
             }
         }
         bool gotone = false;
         int priority = 1;
         while (!gotone && priority <= 9) {
             for (const KCalendarCore::Todo::Ptr &todo : std::as_const(todos)) {
-                const auto calendar = calendar3(todo);
+                const auto todoCalendar = calendar3(todo);
                 if (!todo->isCompleted() && (todo->priority() == priority)) {
                     if (!taskHeaderWasCreated) {
                         createTaskRow(kil);
                         taskHeaderWasCreated = true;
                     }
-                    appendTodo(calendar, todo);
+                    appendTodo(todoCalendar, todo);
                     gotone = true;
                 }
             }
@@ -171,15 +171,15 @@ void WhatsNextView::updateView()
         }
     }
 
-    QStringList myEmails(CalendarSupport::KCalPrefs::instance()->allEmails());
+    const QStringList myEmails(CalendarSupport::KCalPrefs::instance()->allEmails());
     int replies = 0;
     events.clear();
-    for (const auto &calendar : calendars()) {
+    for (const auto &calendar : cals) {
         events += calendar->events(QDate::currentDate(), QDate(2975, 12, 6), QTimeZone::systemTimeZone());
     }
     for (const KCalendarCore::Event::Ptr &ev : std::as_const(events)) {
-        const auto calendar = calendar3(ev);
-        KCalendarCore::Attendee me = ev->attendeeByMails(myEmails);
+        const auto evCalendar = calendar3(ev);
+        const KCalendarCore::Attendee me = ev->attendeeByMails(myEmails);
         if (!me.isNull()) {
             if (me.status() == KCalendarCore::Attendee::NeedsAction && me.RSVP()) {
                 if (replies == 0) {
@@ -192,18 +192,18 @@ void WhatsNextView::updateView()
                     mText += "<table>\n"_L1;
                 }
                 replies++;
-                appendEvent(calendar, ev);
+                appendEvent(evCalendar, ev);
             }
         }
     }
 
     todos.clear();
-    for (const auto &calendar : calendars()) {
+    for (const auto &calendar : cals) {
         todos += calendar->todos();
     }
     for (const KCalendarCore::Todo::Ptr &to : std::as_const(todos)) {
-        const auto calendar = calendar3(to);
-        KCalendarCore::Attendee me = to->attendeeByMails(myEmails);
+        const auto todoCalendar = calendar3(to);
+        const KCalendarCore::Attendee me = to->attendeeByMails(myEmails);
         if (!me.isNull()) {
             if (me.status() == KCalendarCore::Attendee::NeedsAction && me.RSVP()) {
                 if (replies == 0) {
@@ -216,7 +216,7 @@ void WhatsNextView::updateView()
                     mText += "<table>\n"_L1;
                 }
                 replies++;
-                appendEvent(calendar, to);
+                appendEvent(todoCalendar, to);
             }
         }
     }
@@ -295,7 +295,7 @@ void WhatsNextView::appendEvent(const Akonadi::CollectionCalendar::Ptr &calendar
 
 void WhatsNextView::appendTodo(const Akonadi::CollectionCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &incidence)
 {
-    Akonadi::Item aitem = calendar->item(incidence);
+    const Akonadi::Item aitem = calendar->item(incidence);
     if (mTodos.contains(aitem)) {
         return;
     }
@@ -331,7 +331,7 @@ static std::optional<Akonadi::Item::Id> idFromQuery(const QUrlQuery &query, cons
 
 void WhatsNextView::showIncidence(const QUrl &uri)
 {
-    QUrlQuery query(uri);
+    const QUrlQuery query(uri);
     const auto itemId = idFromQuery(query, QStringLiteral("itemId"));
     const auto calendarId = idFromQuery(query, QStringLiteral("calendarId"));
 
